docker

package
v0.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetFeatureContainerStatus

func GetFeatureContainerStatus(projectName, featureName string) (map[string]string, error)

GetFeatureContainerStatus returns the status of containers for a feature

func GetRunningFeatures

func GetRunningFeatures(projectName string) ([]string, error)

GetRunningFeatures returns a list of running feature names

func IsFeatureRunning

func IsFeatureRunning(projectName, featureName string) bool

IsFeatureRunning checks if a specific feature worktree is running

func StopFeature

func StopFeature(projectName, featureName string, worktreePath string, projectInfo map[string]string) error

StopFeature stops a specific feature worktree using a multi-tier approach It stops containers for all active projects (backend, frontend, etc.) projectInfo maps project directory to its compose project name

Types

This section is empty.

Jump to