Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetFeatureContainerStatus ¶
GetFeatureContainerStatus returns the status of containers for a feature
func GetRunningFeatures ¶
GetRunningFeatures returns a list of running feature names
func IsFeatureRunning ¶
IsFeatureRunning checks if a specific feature worktree is running
func StopFeature ¶
func StopFeature(projectName, featureName string, worktreePath string, projectInfo map[string]string) error
StopFeature stops a specific feature worktree using a multi-tier approach It stops containers for all active projects (backend, frontend, etc.) projectInfo maps project directory to its compose project name
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.